@@ -15,7 +15,7 @@ import concurrent.futures  # noqa: E402
 
 executor = concurrent.futures.ThreadPoolExecutor()
 futures = [
-    executor.submit(getattr(_TimeConsumingTasks, func)())
+    executor.submit(getattr(_TimeConsumingTasks, func))
     for func in dir(_TimeConsumingTasks)
     if not func.startswith("_")
 ]
@@ -42,6 +42,7 @@ del version
 # Environment Variables
 class EnvVarName:
     necst_root: str = "NECST_ROOT"
+    necst_config_name: str = "NECST_CONFIG_NAME"
     ros2_ws: str = "ROS2_WS"
     domain_id: str = "ROS_DOMAIN_ID"
     record_root: str = "NECST_RECORD_ROOT"
@@ -61,7 +62,6 @@ del logger, sys  # get_logger is intentionally kept in the namespace.
 
 
 # Subpackages
-# Submodules
 from . import controllers  # noqa: F401, E402
 from . import interfaces  # noqa: F401, E402
 from . import parameters  # noqa: F401, E402
