@@ -1,6 +1,7 @@
 __all__ = ["config", "configure"]
 
 import os
+import re
 import shutil
 from collections.abc import ItemsView, KeysView, ValuesView
 from pathlib import Path
@@ -12,7 +13,7 @@ from tomlkit.toml_file import TOMLFile
 
 from . import EnvVarName, get_logger
 from .exceptions import NECSTConfigurationError
-from .utils import ValueRange
+from .utils import ValueRange, read_file
 
 logger = get_logger(__name__)
 
@@ -117,15 +118,32 @@ class Configuration:
         return getattr(self.__config, key, None)
 
     def __find_config_path(self) -> Path:
-        candidates = [DefaultNECSTRoot]
+        root_candidates = [DefaultNECSTRoot]
         if EnvVarName.necst_root in os.environ:
-            candidates.insert(0, Path(os.environ[EnvVarName.necst_root]))
+            root_candidates.insert(0, os.environ[EnvVarName.necst_root])
+        config_file_name = os.environ.get(EnvVarName.necst_config_name, "config.toml")
+        candidates = map(lambda x: str(x) + f"/{config_file_name}", root_candidates)
 
         for path in candidates:
-            config_path = path if path.is_file() else path / "config.toml"
-            if config_path.exists():
-                logger.info(f"Imported configuration file '{config_path}'")
-                return config_path
+            try:
+                read_file(path, localonly=True)
+                found = Path(re.sub(r".*://", "", path))
+                logger.info(f"Imported configuration file '{found}'")
+                return found
+            except FileNotFoundError:
+                pass
+
+            try:
+                saveto = DefaultNECSTRoot / "config.toml"
+                read_file(path, localonly=False, saveto=saveto, overwrite=True)
+                logger.info(
+                    f"Imported configuration file '{path}', "
+                    f"which was saved to '{saveto}'"
+                )
+                return saveto
+            except FileNotFoundError:
+                pass
+
         logger.error(
             "Config file not found, using the default parameters. "
             "To create the file with default parameters, run `neclib.configure()`."
